@@ -34,50 +34,49 @@ namespace dht
 {
 	/// Each item may only exist for 30 minutes
 	const bt::Uint32 MAX_ITEM_AGE = 30 * 60 * 1000;
-	
+
 	/**
 	 * @author Joris Guisson
-	 * 
+	 *
 	 * Item in the database, will keep track of an IP and port combination.
 	 * As well as the time it was inserted.
 	 */
 	class DBItem
 	{
-		net::Address addr;
-		bt::TimeStamp time_stamp;
 	public:
 		DBItem();
 		DBItem(const net::Address & addr);
 		DBItem(const DBItem & item);
 		virtual ~DBItem();
-		
+
 		/// See if the item is expired
 		bool expired(bt::TimeStamp now) const;
-		
+
 		/// Get the address of an item
 		const net::Address & getAddress() const {return addr;}
-		
+
 		/**
 		 * Pack this item into a buffer, the buffer needs to big enough to handle IPv6 addresses (so 16 + 2 (for the port))
 		 * @param buf The buffer
 		 * @return The number of bytes used
 		 */
 		bt::Uint32 pack(bt::Uint8* buf) const;
-		
+
 		DBItem & operator = (const DBItem & item);
+	private:
+		net::Address addr;
+		bt::TimeStamp time_stamp;
 	};
-	
+
 	typedef QList<DBItem> DBItemList;
 
 	/**
 	 * @author Joris Guisson
-	 * 
+	 *
 	 * Class where all the key value paires get stored.
 	*/
 	class Database
-	{		
-		bt::PtrMap<dht::Key,DBItemList> items;
-		QMap<dht::Key,bt::TimeStamp> tokens;
+	{
 	public:
 		Database();
 		virtual ~Database();
@@ -87,8 +86,8 @@ namespace dht
 		 * @param key The key
 		 * @param dbi The DBItem to store
 		 */
-		void store(const dht::Key & key,const DBItem & dbi);
-		
+		void store(const dht::Key & key, const DBItem & dbi);
+
 		/**
 		 * Get max_entries items from the database, which have
 		 * the same key, items are taken randomly from the list.
@@ -98,37 +97,42 @@ namespace dht
 		 * @param key The key to search for
 		 * @param dbl The list to store the items in
 		 * @param max_entries The maximum number entries
+		 * @param ip_version Wanted IP version (4 or 6)
 		 */
-		void sample(const dht::Key & key,DBItemList & dbl,bt::Uint32 max_entries);
-		
+		void sample(const dht::Key & key, DBItemList & dbl, bt::Uint32 max_entries, bt::Uint32 ip_version);
+
 		/**
 		 * Expire all items older then 30 minutes
-		 * @param now The time it is now 
+		 * @param now The time it is now
 		 * (we pass this along so we only have to calculate it once)
 		 */
 		void expire(bt::TimeStamp now);
-		
+
 		/**
 		 * Generate a write token, which will give peers write access to
 		 * the DB.
 		 * @param addr The address of the peer
-		 * @return A Key
+		 * @return A QByteArray
 		 */
-		dht::Key genToken(const net::Address & addr);
-		
+		QByteArray genToken(const net::Address & addr);
+
 		/**
 		 * Check if a received token is OK.
 		 * @param token The token received
 		 * @param addr The address of the peer
 		 * @return true if the token was given to this peer, false other wise
 		 */
-		bool checkToken(const dht::Key & token,const net::Address & addr);
-		
+		bool checkToken(const QByteArray & token, const net::Address & addr);
+
 		/// Test whether or not the DB contains a key
 		bool contains(const dht::Key & key) const;
-		
+
 		/// Insert an empty item (only if it isn't already in the DB)
 		void insert(const dht::Key & key);
+		
+	private:
+		bt::PtrMap<dht::Key, DBItemList> items;
+		QMap<QByteArray, bt::TimeStamp> tokens;
 	};
 
 }
