@@ -86,7 +86,7 @@ namespace dht
 				cnt->addNode(d);
 			}
 			j++;
-			i++;
+			++i;
 		}
 	}
 
