@@ -22,13 +22,14 @@
 #include "webseed.h"
 
 #include <QTimer>
-#include <klocale.h>
+#include <klocalizedstring.h>
 #include <kprotocolmanager.h>
 #include <util/log.h>
 #include <torrent/torrent.h>
 #include <diskio/chunkmanager.h>
 #include <diskio/piecedata.h>
 #include <net/socketmonitor.h>
+#include <peer/peermanager.h>
 #include "httpconnection.h"
 
 namespace bt
@@ -41,7 +42,7 @@ namespace bt
 	
 	const Uint32 RETRY_INTERVAL = 30;
 
-	WebSeed::WebSeed(const KUrl & url,bool user,const Torrent & tor,ChunkManager & cman) : WebSeedInterface(url,user),tor(tor),cman(cman)
+	WebSeed::WebSeed(const QUrl &url,bool user,const Torrent & tor,ChunkManager & cman) : WebSeedInterface(url,user),tor(tor),cman(cman)
 	{
 		first_chunk = last_chunk = tor.getNumChunks() + 1;
 		num_failures = 0;
@@ -51,7 +52,7 @@ namespace bt
 		status = i18n("Not connected");
 		up_gid = down_gid = 0;
 		cur_chunk = -1;
-		connect(&retry_timer,SIGNAL(timeout()),this,SLOT(reset()));
+		connect(&retry_timer, &QTimer::timeout, this, &WebSeed::reset);
 		retry_timer.setSingleShot(true);
 	}
 
@@ -107,7 +108,7 @@ namespace bt
 	{
 		setEnabled(false);
 		status = reason;
-		Out(SYS_CON|LOG_IMPORTANT) << "Auto disabled webseed " << url.prettyUrl() << endl;
+		Out(SYS_CON|LOG_IMPORTANT) << "Auto disabled webseed " << url.toDisplayString() << endl;
 	}
 
 
@@ -119,25 +120,34 @@ namespace bt
 	Uint32 WebSeed::getDownloadRate() const
 	{
 		if (conn)
-			return (Uint32)conn->getDownloadRate();
+			return conn->getDownloadRate();
 		else
 			return 0;
 	}
 	
 	void WebSeed::connectToServer()
 	{
-		KUrl dst = url;
+		if(!token)
+			token = PeerManager::connectionLimits().acquire(tor.getInfoHash());
+		
+		if(!token)
+		{
+			retryLater();
+			return;
+		}
+			
+		QUrl dst = url;
 		if (redirected_url.isValid())
 			dst = redirected_url;
 		
 		if (!proxy_enabled)
 		{
 			QString proxy = KProtocolManager::proxyForUrl(dst); // Use KDE settings
-			if (proxy.isNull() || proxy == "DIRECT")
+			if (proxy.isNull() || proxy == QLatin1String("DIRECT"))
 				conn->connectTo(dst); // direct connection 
 			else
 			{
-				KUrl proxy_url(proxy);
+				QUrl proxy_url(proxy);
 				conn->connectToProxy(proxy_url.host(),proxy_url.port() <= 0 ? 80 : proxy_url.port());
 			}
 		}
@@ -156,7 +166,7 @@ namespace bt
 		if (!enabled)
 			return;
 		
-		//Out(SYS_CON|LOG_DEBUG) << "WebSeed: downloading " << first << "-" << last << " from " << url.prettyUrl() << endl;
+		//Out(SYS_CON|LOG_DEBUG) << "WebSeed: downloading " << first << "-" << last << " from " << url.toDisplayString() << endl;
 		// open connection and connect if needed
 		if (!conn)
 		{
@@ -183,6 +193,7 @@ namespace bt
 		bytes_of_cur_chunk = 0;
 		
 		QString path = url.path();
+		QString query = url.query();
 		if (path.endsWith('/'))
 			path += tor.getNameSuggestion();
 		
@@ -202,7 +213,7 @@ namespace bt
 				range_queue.pop_front();
 				const TorrentFile & tf = tor.getFile(r.file);
 				QString host = redirected_url.isValid() ? redirected_url.host() : url.host();
-				conn->get(host,path + '/' + tf.getPath(),r.off,r.len);
+				conn->get(host,path + '/' + tf.getPath(),query,r.off,r.len);
 			}
 		}
 		else
@@ -215,13 +226,14 @@ namespace bt
 				len += tor.getChunkSize(); 
 			
 			QString host = redirected_url.isValid() ? redirected_url.host() : url.host();
-			conn->get(host,path,first_chunk * tor.getChunkSize(),len);
+			conn->get(host,path,query,first_chunk * tor.getChunkSize(),len);
 		}
 	}
 	
 	void WebSeed::continueCurChunk()
 	{
 		QString path = url.path();
+		QString query = url.query();
 		if (path.endsWith('/') && !isUserCreated())
 			path += tor.getNameSuggestion();
 		
@@ -245,7 +257,7 @@ namespace bt
 				{
 					const TorrentFile & tf = tor.getFile(r.file);
 					QString host = redirected_url.isValid() ? redirected_url.host() : url.host();
-					conn->get(host,path + '/' + tf.getPath(),r.off,r.len);
+					conn->get(host,path + '/' + tf.getPath(),query,r.off,r.len);
 					break;
 				}
 				length += r.len;
@@ -261,7 +273,7 @@ namespace bt
 				len += tor.getChunkSize(); 
 			
 			QString host = redirected_url.isValid() ? redirected_url.host() : url.host();
-			conn->get(host,path,first_chunk * tor.getChunkSize() + bytes_of_cur_chunk,len - bytes_of_cur_chunk);
+			conn->get(host,path,query,first_chunk * tor.getChunkSize() + bytes_of_cur_chunk,len - bytes_of_cur_chunk);
 		}
 		chunkStarted(cur_chunk);
 	}
@@ -275,13 +287,13 @@ namespace bt
 	
 		if (!current)
 		{
-			current = new WebSeedChunkDownload(this,url.prettyUrl(),chunk,pieces_count);
+			current = new WebSeedChunkDownload(this,url.toDisplayString(),chunk,pieces_count);
 			chunkDownloadStarted(current,chunk);
 		}
 		else if (current->chunk != chunk)
 		{
 			chunkStopped();
-			current = new WebSeedChunkDownload(this,url.prettyUrl(),chunk,pieces_count);
+			current = new WebSeedChunkDownload(this,url.toDisplayString(),chunk,pieces_count);
 			chunkDownloadStarted(current,chunk);
 		}
 	}
@@ -317,6 +329,7 @@ namespace bt
 				}
 				delete conn;
 				conn = 0;
+				token.clear();
 				chunkStopped();
 				first_chunk = last_chunk = cur_chunk = tor.getNumChunks() + 1;
 				num_failures++;
@@ -332,6 +345,7 @@ namespace bt
 				Out(SYS_CON|LOG_DEBUG) << "WebSeed: connection closed" << endl;
 				delete conn;
 				conn = 0;
+				token.clear();
 				
 				status = i18n("Connection closed");
 				chunkStopped();
@@ -364,6 +378,7 @@ namespace bt
 					}
 					
 					QString path = url.path();
+					QString query = url.query();
 					if (path.endsWith('/'))
 						path += tor.getNameSuggestion();
 					
@@ -372,7 +387,7 @@ namespace bt
 					range_queue.pop_front();
 					const TorrentFile & tf = tor.getFile(r.file);
 					QString host = redirected_url.isValid() ? redirected_url.host() : url.host();
-					conn->get(host,path + '/' + tf.getPath(),r.off,r.len);
+					conn->get(host,path + '/' + tf.getPath(),query,r.off,r.len);
 				}
 				status = conn->getStatusString();
 			}
@@ -522,11 +537,12 @@ namespace bt
 		}
 	}
 	
-	void WebSeed::redirected(const KUrl & to_url)
+	void WebSeed::redirected(const QUrl &to_url)
 	{
 		delete conn;
 		conn = 0;
-		if (to_url.isValid() && to_url.protocol() == "http")
+		token.clear();
+		if (to_url.isValid() && to_url.scheme() == QLatin1String("http"))
 		{
 			redirected_url = to_url;
 			download(cur_chunk,last_chunk);
@@ -542,7 +558,7 @@ namespace bt
 	void WebSeed::retryLater()
 	{
 		num_failures = 3;
-		status = i18n("Unused for %1 seconds (Too many connection failures)", RETRY_INTERVAL);
+		status = i18np("Unused for %1 second (Too many connection failures)", "Unused for %1 seconds (Too many connection failures)", RETRY_INTERVAL);
 		retry_timer.start(RETRY_INTERVAL * 1000);
 	}
 
@@ -570,4 +586,3 @@ namespace bt
 		
 
 }
-#include "webseed.moc"
