@@ -21,13 +21,14 @@
 #define BTTORRENTINTERFACE_H
 
 #include <QSharedPointer>
-#include <QWeakPointer>
+#include <QPointer>
+#include <QUrl>
+
 #include <ktorrent_export.h>
 #include <util/constants.h>
 #include <interfaces/trackerslist.h>
 #include <torrent/torrentstats.h>
 #include <torrent/torrentfilestream.h>
-#include <QUrl>
 
 #ifdef ERROR
 #undef ERROR
@@ -90,7 +91,7 @@ namespace bt
 		Q_OBJECT
 	public:
 		TorrentInterface();
-		virtual ~TorrentInterface();
+		~TorrentInterface() override;
 
 		/// Set the URL which the torrent was loaded from
 		void setLoadUrl(const QUrl &u) {url = u;}
@@ -464,9 +465,9 @@ namespace bt
 		virtual void setSuperSeeding(bool on) = 0;
 		
 		typedef QSharedPointer<TorrentInterface> Ptr;
-		typedef QWeakPointer<TorrentInterface> WPtr;
+		typedef QPointer<TorrentInterface> WPtr;
 
-	signals:
+	Q_SIGNALS:
 		/**
 		 * Emitted when we have finished downloading.
 		 * @param me The object who emitted the signal
