@@ -38,10 +38,10 @@ namespace mse
 		Q_OBJECT
 	public:
 		EncryptedServerAuthenticate(mse::EncryptedPacketSocket::Ptr sock);
-		virtual ~EncryptedServerAuthenticate();
+		~EncryptedServerAuthenticate() override;
 
-	private slots:
-		virtual void onReadyRead();
+	private Q_SLOTS:
+		void onReadyRead() override;
 		
 	private:
 		void handleYA();
