@@ -37,11 +37,21 @@ namespace bt
 			return '0' + (i - 52);
 	}
 
+	QString charToNumber(QChar c)
+	{
+		if (c >= 'A' && c <= 'F')
+			return QString::number(c.toLatin1() - 'A' + 10);
+		else if (c >= 'z' && c <= 'f')
+			return QString::number(c.toLatin1() - 'a' + 10);
+		else
+			return c;
+	}
+
 	
 	PeerID::PeerID()
 	{
 		srand(time(0));
-		memcpy(id,bt::PeerIDPrefix().toLatin1(),8);
+		memcpy(id, bt::PeerIDPrefix().toLatin1().constData(), 8);
 		for (int i = 8;i < 20;i++)
 			id[i] = RandomLetterOrNumber(); 
 		client_name = identifyClient();
@@ -120,15 +130,18 @@ namespace bt
 		{
 			// Keep things a bit alphabetic to make it easier add new ones
 			//AZUREUS STYLE
+			Map[QStringLiteral("7T")] = QStringLiteral("aTorrent");
+			Map[QStringLiteral("AB")] = QStringLiteral("AnyEvent::BitTorrent");
 			Map[QStringLiteral("AG")] = QStringLiteral("Ares");
-			Map[QStringLiteral("A~")] = QStringLiteral("Ares");
+			Map[QStringLiteral("AR")] = QStringLiteral("Arctic");
 			Map[QStringLiteral("AT")] = QStringLiteral("Artemis");
 			Map[QStringLiteral("AV")] = QStringLiteral("Avicora");
 			Map[QStringLiteral("AX")] = QStringLiteral("BitPump");
-			Map[QStringLiteral("AR")] = QStringLiteral("Arctic");
 			Map[QStringLiteral("AZ")] = QStringLiteral("Azureus");
+			Map[QStringLiteral("A~")] = QStringLiteral("Ares");
 			Map[QStringLiteral("BB")] = QStringLiteral("BitBuddy");
 			Map[QStringLiteral("BC")] = QStringLiteral("BitComet");
+			Map[QStringLiteral("BE")] = QStringLiteral("Baretorrent");
 			Map[QStringLiteral("BF")] = QStringLiteral("Bitflu");
 			Map[QStringLiteral("BG")] = QStringLiteral("BTGetit");
 			Map[QStringLiteral("BL")] = QStringLiteral("BitBlinder");
@@ -137,6 +150,8 @@ namespace bt
 			Map[QStringLiteral("BP")] = QStringLiteral("BitTorrent Pro");
 			Map[QStringLiteral("BR")] = QStringLiteral("BitRocket");
 			Map[QStringLiteral("BS")] = QStringLiteral("BTSlave");
+			Map[QStringLiteral("BT")] = QStringLiteral("mainline BitTorrent");
+			Map[QStringLiteral("Bt")] = QStringLiteral("Bt");
 			Map[QStringLiteral("BW")] = QStringLiteral("BitWombat");
 			Map[QStringLiteral("BX")] = QStringLiteral("BitTorrent X");
 			Map[QStringLiteral("CD")] = QStringLiteral("Enhanced CTorrent");
@@ -147,43 +162,56 @@ namespace bt
 			Map[QStringLiteral("EB")] = QStringLiteral("EBit");
 			Map[QStringLiteral("ES")] = QStringLiteral("electric sheep");
 			Map[QStringLiteral("FC")] = QStringLiteral("FileCroc");
+			Map[QStringLiteral("FD")] = QStringLiteral("Free Download Manager");
 			Map[QStringLiteral("FT")] = QStringLiteral("FoxTorrent");
-			Map[QStringLiteral("GS")] = QStringLiteral("GSTorrent");
+			Map[QStringLiteral("FX")] = QStringLiteral("Freebox BitTorrent");
 			Map[QStringLiteral("G3")] = QStringLiteral("G3 Torrent");
+			Map[QStringLiteral("GS")] = QStringLiteral("GSTorrent");
 			Map[QStringLiteral("HK")] = QStringLiteral("Hekate");
 			Map[QStringLiteral("HL")] = QStringLiteral("Halite");
+			Map[QStringLiteral("HM")] = QStringLiteral("hMule");
 			Map[QStringLiteral("HN")] = QStringLiteral("Hydranode");
+			Map[QStringLiteral("IL")] = QStringLiteral("iLivid");
+			Map[QStringLiteral("JS")] = QStringLiteral("Justseed.it client");
+			Map[QStringLiteral("JT")] = QStringLiteral("JavaTorrent");
 			Map[QStringLiteral("KG")] = QStringLiteral("KGet");
 			Map[QStringLiteral("KT")] = QStringLiteral("KTorrent"); // lets not forget our own client
 			Map[QStringLiteral("LC")] = QStringLiteral("LeechCraft");
 			Map[QStringLiteral("LH")] = QStringLiteral("LH-ABC");
-			Map[QStringLiteral("lt")] = QStringLiteral("libTorrent");
-			Map[QStringLiteral("LT")] = QStringLiteral("libtorrent");
 			Map[QStringLiteral("LP")] = QStringLiteral("Lphant");
+			Map[QStringLiteral("LT")] = QStringLiteral("libtorrent");
+			Map[QStringLiteral("lt")] = QStringLiteral("libTorrent");
 			Map[QStringLiteral("LW")] = QStringLiteral("LimeWire");
 			Map[QStringLiteral("MK")] = QStringLiteral("Meerkat");
 			Map[QStringLiteral("ML")] = QStringLiteral("MLDonkey");
 			Map[QStringLiteral("MO")] = QStringLiteral("MonoTorrent");
 			Map[QStringLiteral("MP")] = QStringLiteral("MooPolice");
+			Map[QStringLiteral("MR")] = QStringLiteral("Miro");
 			Map[QStringLiteral("MT")] = QStringLiteral("MoonLight");
+			Map[QStringLiteral("NB")] = QStringLiteral("Net::BitTorrent");
 			Map[QStringLiteral("NE")] = QStringLiteral("BT Next Evolution");
 			Map[QStringLiteral("NX")] = QStringLiteral("Net Transport");
 			Map[QStringLiteral("OS")] = QStringLiteral("OneSwarm");
 			Map[QStringLiteral("OT")] = QStringLiteral("OmegaTorrent");
+			Map[QStringLiteral("PB")] = QStringLiteral("Protocol::BitTorrent");
 			Map[QStringLiteral("PD")] = QStringLiteral("Pando");
 			Map[QStringLiteral("qB")] = QStringLiteral("qBittorrent");
 			Map[QStringLiteral("QD")] = QStringLiteral("QQDownload");
 			Map[QStringLiteral("QT")] = QStringLiteral("Qt 4 Torrent example");
 			Map[QStringLiteral("RT")] = QStringLiteral("Retriever");
 			Map[QStringLiteral("RZ")] = QStringLiteral("RezTorrent");
-			Map[QStringLiteral("S~")] = QStringLiteral("Shareaza alpha/beta");
 			Map[QStringLiteral("SB")] = QStringLiteral("Swiftbit");
 			Map[QStringLiteral("SD")] = QStringLiteral("Thunder");
 			Map[QStringLiteral("SM")] = QStringLiteral("SoMud");
+			Map[QStringLiteral("SP")] = QStringLiteral("BitSpirit");
 			Map[QStringLiteral("SS")] = QStringLiteral("SwarmScope");
-			Map[QStringLiteral("ST")] = QStringLiteral("SymTorrent");
 			Map[QStringLiteral("st")] = QStringLiteral("sharktorrent");
+			Map[QStringLiteral("ST")] = QStringLiteral("SymTorrent");
 			Map[QStringLiteral("SZ")] = QStringLiteral("Shareaza");
+			Map[QStringLiteral("S~")] = QStringLiteral("Shareaza alpha/beta");
+			Map[QStringLiteral("TB")] = QStringLiteral("Torch");
+			Map[QStringLiteral("TE")] = QStringLiteral("terasaur Seed Bank");
+			Map[QStringLiteral("TL")] = QStringLiteral("Tribler");
 			Map[QStringLiteral("TN")] = QStringLiteral("Torrent .NET");
 			Map[QStringLiteral("TR")] = QStringLiteral("Transmission");
 			Map[QStringLiteral("TS")] = QStringLiteral("Torrent Storm");
@@ -192,8 +220,11 @@ namespace bt
 			Map[QStringLiteral("UM")] = QStringLiteral("%1Torrent for Mac").arg(QChar(0x00B5)); // µTorrent, 0x00B5 is unicode for µ
 			Map[QStringLiteral("UT")] = QStringLiteral("%1Torrent").arg(QChar(0x00B5)); // µTorrent, 0x00B5 is unicode for µ
 			Map[QStringLiteral("VG")] = QStringLiteral("Vagaa");
+			Map[QStringLiteral("WD")] = QStringLiteral("WebTorrent Desktop");
 			Map[QStringLiteral("WT")] = QStringLiteral("BitLet");
+			Map[QStringLiteral("WW")] = QStringLiteral("WebTorrent");
 			Map[QStringLiteral("WY")] = QStringLiteral("FireTorrent");
+			Map[QStringLiteral("XF")] = QStringLiteral("Xfplay");
 			Map[QStringLiteral("XL")] = QStringLiteral("Xunlei");
 			Map[QStringLiteral("XS")] = QStringLiteral("XSwifter");
 			Map[QStringLiteral("XT")] = QStringLiteral("Xan Torrent");
@@ -222,18 +253,26 @@ namespace bt
 			Map[QStringLiteral("Q1")] = QStringLiteral("Queen Bee");
 			Map[QStringLiteral("AP")] = QStringLiteral("AllPeers");
 			Map[QStringLiteral("QVOD")] = QStringLiteral("Qvod");
+			Map[QStringLiteral("TIX")] = QStringLiteral("Tixati");
 			first = false;
 		}
 
-		QString name = i18n("Unknown client");
+		QString name;
 		if (peer_id.at(0) == '-' &&
 			peer_id.at(1).isLetter() &&
 			peer_id.at(2).isLetter() ) //AZ style
 		{
 			QString ID(peer_id.mid(1,2));
-			if (Map.contains(ID))
-				name = Map[ID] + ' ' + peer_id.at(3) + '.' + peer_id.at(4) + '.'
-					+ peer_id.at(5) + '.' + peer_id.at(6);
+			if (ID == QLatin1String("ML"))
+			{
+				name = Map[ID];
+				const int dash_pos = peer_id.indexOf('-', 3);
+				if (dash_pos != -1)
+					name += ' ' + peer_id.mid(3,dash_pos-3);
+			}
+			else if (Map.contains(ID))
+				name = Map[ID] + ' ' + charToNumber(peer_id.at(3)) + '.' + charToNumber(peer_id.at(4)) + '.'
+					+ charToNumber(peer_id.at(5));
 		}
 		else if (peer_id.at(0).isLetter() &&
 				peer_id.at(1).isDigit() &&
@@ -302,6 +341,15 @@ namespace bt
 		{
 			name = Map[QStringLiteral("QVOD")];
 		}
+		else if (peer_id.startsWith(QLatin1String("TIX")))
+		{
+			name = Map[QStringLiteral("TIX")] + ' ' + peer_id.at(3) + peer_id.at(4) + '.'
+				+ peer_id.at(5) + peer_id.at(6);
+		}
+		if (name.isEmpty())
+		{
+			name = i18n("Unknown client");
+		}
 			
 		return name;
 	}
