@@ -17,8 +17,8 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
-#include <util/log.h>
 #include "jobqueue.h"
+#include <util/log.h>
 #include "job.h"
 #include "torrentcontrol.h"
 
@@ -72,7 +72,7 @@ namespace bt
 
 	void JobQueue::jobDone(KJob* job)
 	{
-		if (queue.front() != job)
+		if (queue.isEmpty() || queue.front() != job)
 			return;
 		
 		// remove the job and start the next
