@@ -416,7 +416,8 @@ namespace bt
 	{
 		timer.stop();
 		active_job = 0;
-		if (j->error() && data.size() == 0)
+		KIOAnnounceJob* st = (KIOAnnounceJob*)j;
+		if (st->IsErrorPage() || (j->error() && data.size() == 0))
 		{
 			QString err = error;
 			error.clear();
@@ -424,6 +425,12 @@ namespace bt
 				err = j->errorString();
 
 			Out(SYS_TRK | LOG_IMPORTANT) << "Error : " << err << endl;
+
+			if (st->IsErrorPage())
+			{
+				Out(SYS_TRK | LOG_IMPORTANT) << "HTTP Error page : " << QString::fromStdString(st->replyData().toStdString()) << endl;
+			}
+
 			if (QUrlQuery(url).queryItemValue(QStringLiteral("event")) != QLatin1String("stopped"))
 			{
 				failures++;
@@ -487,7 +494,7 @@ namespace bt
 		if (proxy_on)
 		{
 			QString p = QString("%1:%2").arg(proxy).arg(proxy_port);
-			if (!p.startsWith("http://"))
+			if (!p.startsWith(QLatin1String("http://")))
 				p = "http://" + p;
 			// set the proxy if the doNotUseKDEProxy ix enabled (URL must be valid to)
 			QUrl url(p);
@@ -551,6 +558,7 @@ namespace bt
 		}
 #endif
 
+		time_out = false;
 		timer.start(60*1000);
 		status = TRACKER_ANNOUNCING;
 		requestPending();
@@ -560,6 +568,7 @@ namespace bt
 	{
 		if (active_job)
 		{
+			time_out = true;
 			error = i18n("Timeout contacting tracker %1", url.toString());
 			active_job->kill(KJob::EmitResult);
 		}
