@@ -366,7 +366,7 @@ namespace bt
 
 	bool XfsPreallocate(const QString & path, Uint64 size)
 	{
-		int fd = ::open(QFile::encodeName(path), O_RDWR | O_LARGEFILE);
+		int fd = ::open(QFile::encodeName(path).constData(), O_RDWR | O_LARGEFILE);
 		if (fd < 0)
 			throw Error(i18n("Cannot open %1: %2",path,strerror(errno)));
 
@@ -692,7 +692,7 @@ namespace bt
         if (fptr.open(QIODevice::ReadOnly))
             return fptr.readAll();
         else
-            throw Error(i18n("Unable to open file %1: %2").arg(path).arg(fptr.errorString()));
+            throw Error(i18n("Unable to open file %1: %2", path, fptr.errorString()));
     }
 
 }
