@@ -21,7 +21,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <arpa/inet.h>
-#include <Qca-qt5/QtCrypto/QtCrypto>
+#include <QtCrypto>
 #include "functions.h"
 
 
@@ -30,7 +30,7 @@ namespace bt
 {
 	static QCA::Initializer qca_init;
 
-	SHA1HashGen::SHA1HashGen() : h(new QCA::Hash("sha1"))
+	SHA1HashGen::SHA1HashGen() : h(new QCA::Hash(QStringLiteral("sha1")))
 	{
 		memset(result,9,20);
 	}
